@@ -241,6 +241,8 @@ def file_path(value, **kwargs):
     value = re.sub(r'(\\|\/)', path_sep, value)
     regex = re.compile(rf'{path_sep}+')
     value = re.sub(regex, path_sep, value)
+    if len(value) > 250:
+        value = clean_path(value)
     if escape_spaces:
         path_array = value.split(os.path.sep)
         new_path_array = []
@@ -253,5 +255,15 @@ def file_path(value, **kwargs):
     return value
 
 
+def clean_path(path):
+    path = path.replace('/', os.sep).replace('\\', os.sep)
+    if os.sep == '\\' and '\\\\?\\' not in path:
+        # fix for Windows 260 char limit
+        relative_levels = len([directory for directory in path.split(os.sep) if directory == '..'])
+        cwd = [directory for directory in os.getcwd().split(os.sep)] if ':' not in path else []
+        path = '\\\\?\\' + os.sep.join(cwd[:len(cwd)-relative_levels] + [directory for directory in path.split(os.sep) if directory != ''][relative_levels:])
+    return path
+
+
 # ----------========== ALIASES ==========----------
 left_pad = leftPad
