@@ -5,7 +5,7 @@ import random
 import utils.objectUtils as objUtils
 
 
-def generate_hash(value):
+def hash(value):
     '''
         Generates a sha256 hash from the string provided.
 
